@@ -66,6 +66,13 @@ class UNITY_API ApplicationManagerInterface: public QAbstractListModel
      */
     Q_PROPERTY(bool suspended READ suspended WRITE setSuspended NOTIFY suspendedChanged)
 
+    /**
+     * @brief Activate the dash, regardless of its focused state.
+     *
+     * If this is set to true, the dash will not be put to suspend or will be woken up from suspend.
+     */
+    Q_PROPERTY(bool forceDashActive READ forceDashActive WRITE setForceDashActive NOTIFY forceDashActiveChanged)
+
 protected:
     /// @cond
     ApplicationManagerInterface(QObject* parent = 0): QAbstractListModel(parent)
@@ -77,7 +84,6 @@ protected:
         m_roleNames.insert(RoleStage, "stage");
         m_roleNames.insert(RoleState, "state");
         m_roleNames.insert(RoleFocused, "focused");
-        m_roleNames.insert(RoleScreenshot, "screenshot");
 
         connect(this, SIGNAL(rowsInserted(QModelIndex, int, int)), SIGNAL(countChanged()));
         connect(this, SIGNAL(rowsRemoved(QModelIndex, int, int)), SIGNAL(countChanged()));
@@ -100,7 +106,6 @@ public:
         RoleStage,
         RoleState,
         RoleFocused,
-        RoleScreenshot,
     };
 
     /// @cond
@@ -119,6 +124,9 @@ public:
 
     virtual bool suspended() const = 0;
     virtual void setSuspended(bool suspended) = 0;
+
+    virtual bool forceDashActive() const = 0;
+    virtual void setForceDashActive(bool forceDashActive) = 0;
     /// @endcond
 
     /**
@@ -185,18 +193,6 @@ public:
       */
     Q_INVOKABLE virtual bool stopApplication(const QString &appId) = 0;
 
-    /**
-     * @brief Update the screenshot for an application.
-     *
-     * NOTE: Normally the ApplicationManager will update screenshots unfocusing or focusing apps,
-     * However, in cases where you need to show the screenshot while the application is still focused,
-     * you can request the ApplicationManager to update it now.
-     *
-     * @param appId The application for which the screenshot should be updated.
-     * @returns True if the screenshot update operation was scheduled successfully, false otherwise (i.e. the given appId could not be found)
-     */
-    Q_INVOKABLE virtual bool updateScreenshot(const QString &appId) = 0;
-
 Q_SIGNALS:
     /// @cond
     void countChanged();
@@ -220,6 +216,11 @@ Q_SIGNALS:
      */
     void suspendedChanged();
 
+    /**
+     * @brief Will be emitted when the forceDashActive property changes.
+     */
+    void forceDashActiveChanged();
+
     /**
      * @brief Will be emitted when an application was added to the model.
      *
