@@ -54,11 +54,6 @@ QUrl MockApplicationInfo::icon() const
     return m_icon;
 }
 
-QUrl MockApplicationInfo::screenshot() const
-{
-    return m_screenshot;
-}
-
 ApplicationInfoInterface::Stage MockApplicationInfo::stage() const
 {
     return m_stage;
@@ -100,3 +95,33 @@ void MockApplicationInfo::setFocused(bool focused)
         Q_EMIT focusedChanged(focused);
     }
 }
+
+QString MockApplicationInfo::splashTitle() const
+{
+    return "Foo Bar";
+}
+
+QUrl MockApplicationInfo::splashImage() const
+{
+    return QUrl();
+}
+
+bool MockApplicationInfo::splashShowHeader() const
+{
+    return true;
+}
+
+QColor MockApplicationInfo::splashColor() const
+{
+    return QColor(0,0,0,0);
+}
+
+QColor MockApplicationInfo::splashColorHeader() const
+{
+    return QColor(0,0,0,0);
+}
+
+QColor MockApplicationInfo::splashColorFooter() const
+{
+    return QColor(0,0,0,0);
+}
