@@ -36,7 +36,6 @@ public:
     QString name() const;
     QString comment() const;
     QUrl icon() const;
-    QUrl screenshot() const;
 
     ApplicationInfoInterface::Stage stage() const;
     void setStage(ApplicationInfoInterface::Stage stage);
@@ -47,12 +46,18 @@ public:
     bool focused() const;
     void setFocused(bool focused);
 
+    QString splashTitle() const override;
+    QUrl splashImage() const override;
+    bool splashShowHeader() const override;
+    QColor splashColor() const override;
+    QColor splashColorHeader() const override;
+    QColor splashColorFooter() const override;
+
 private:
     QString m_appId;
     QString m_name;
     QString m_comment;
     QUrl m_icon;
-    QUrl m_screenshot;
     ApplicationInfoInterface::Stage m_stage;
     ApplicationInfoInterface::State m_state;
     bool m_focused;
